@@ -4,7 +4,7 @@ package Yahoo::Marketing::BasicResponse;
 
 use strict; use warnings;
 
-use base qw/Yahoo::Marketing::ResponseType/;
+use base qw/Yahoo::Marketing::ComplexType/;
 
 =head1 NAME
 
@@ -16,6 +16,7 @@ sub _user_setable_attributes {
     return ( qw/ 
                  errors
                  operationSucceeded
+                 warnings
             /  );
 }
 
@@ -28,14 +29,11 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
                            __PACKAGE__->_read_only_attributes
                          );
 
-sub _type_field {
-    return;
-}
 
 1;
 =head1 SYNOPSIS
 
-See L<http://ysm.techportal.searchmarketing.yahoo.com/docs/reference/dataObjects.asp> for documentation of the various data objects.
+See L<http://searchmarketing.yahoo.com/developer/docs/V4/reference/dataObjects.php> for documentation of the various data objects.
 
 
 =cut
@@ -52,6 +50,7 @@ Creates a new instance
 
     errors
     operationSucceeded
+    warnings
 
 =back
 
