@@ -16,7 +16,7 @@ Yahoo::Marketing::CompanyService - an object that provides access to Yahoo Marke
 
 See EWS documentation online for available SOAP methods:
 
-L<http://ysm.techportal.searchmarketing.yahoo.com/docs/reference/services/CompanyService.asp>
+L<http://searchmarketing.yahoo.com/developer/docs/V3/reference/services/CompanyService.php>
 
 Also see perldoc Yahoo::Marketing::Service for functionality common to all service modules.
 
